@@ -22,88 +22,59 @@
 #include <gnome.h>
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
-#include <egg-screen-help.h>
 #include "geyes.h"
 
 #define UPDATE_TIMEOUT 100
 
+/* FIXME crashes, need to fix */
 static void
-applet_set_back_pixmap (GtkWidget *widget, const gchar *pixmap)
+applet_set_back_pixmap (PanelApplet *applet, GtkWidget *widget, GdkPixmap *pixmap)
 {
-#ifdef FIXME    
-        GdkPixbuf *pixbuf;
-        GdkPixmap *pm;
-        GtkStyle *new_style;
-        if (!pixmap || strcmp (pixmap, "") == 0) {
-                new_style = gtk_style_copy (widget->style);
-                gtk_style_ref (new_style);
-                pm = new_style->bg_pixmap [GTK_STATE_NORMAL];
+	GtkStyle *new_style;
 
-                if (pm) 
-                        gdk_imlib_free_pixmap (pm);
-
-                new_style->bg_pixmap [GTK_STATE_NORMAL] = NULL;
-                gtk_widget_set_style (widget, new_style);
-                gtk_style_unref (new_style);
-                return;
-        }
-        if (!g_file_exists (pixmap)) 
-                return;
-        
-        pixbuf = gdk_pixbuf_new_from_file (pixmap, NULL);
-        /*imlib_image = gdk_imlib_load_image (pixmap);*/
-        if (!pixbuf)
-                return;
-        
-        /*gdk_imlib_render (imlib_image, 
-	  imlib_image->rgb_width,
-	  imlib_image->rgb_height);*/
-        /*pm = gdk_imlib_move_image (imlib_image);*/
-        gdk_pixbuf_render_pixmap_and_mask (pixbuf,&pm,NULL,0);
         new_style = gtk_style_copy (widget->style);
         gtk_style_ref (new_style);
-
-        if (new_style->bg_pixmap [GTK_STATE_NORMAL]) 
-                gdk_imlib_free_pixmap (new_style->bg_pixmap [GTK_STATE_NORMAL]);
-
-        new_style->bg_pixmap [GTK_STATE_NORMAL] = pm;
+/* FIXME should this be done ? */
+/*
+        if (new_style->bg_pixmap [GTK_STATE_NORMAL])
+		g_object_unref (new_style->bg_pixmap [GTK_STATE_NORMAL]);
+*/
+        new_style->bg_pixmap [GTK_STATE_NORMAL] = pixmap;
         gtk_widget_set_style (widget, new_style);
         gtk_style_unref (new_style);
-        gdk_pixbuf_unref (pixbuf);
-#endif
 }
 
 static void
-applet_back_change (PanelApplet *a,
-		    PanelAppletBackgroundType  type,
-		    GdkColor                  *color,
-		    const gchar               *pixmap,
-		    EyesApplet                *eyes_applet) 
+applet_back_change (PanelApplet			*a,
+		    PanelAppletBackgroundType	type,
+		    GdkColor			*color,
+		    GdkPixmap			*pixmap,
+		    EyesApplet			*eyes_applet) 
 {
 	GtkRcStyle *rc_style = gtk_rc_style_new ();
-	gint i;
-                
+
 	switch (type) {
 	case PANEL_PIXMAP_BACKGROUND:
-                applet_set_back_pixmap (eyes_applet->vbox, pixmap);
+		gtk_widget_modify_style (GTK_WIDGET (eyes_applet->applet), rc_style);
+/* FIXME can't get to work */
+//		applet_set_back_pixmap (a, GTK_WIDGET (eyes_applet->applet), pixmap);
 		break;
-        case PANEL_COLOR_BACKGROUND:
-                for (i = 0; i < eyes_applet->num_eyes; i++) {
-                	gtk_widget_modify_bg (eyes_applet->eyes[i],
-					      GTK_STATE_NORMAL,
-			    	       	      color);
-        	}
+
+	case PANEL_COLOR_BACKGROUND:
+		gtk_widget_modify_bg (GTK_WIDGET (eyes_applet->applet), GTK_STATE_NORMAL, color);
 		break;
+
+	case PANEL_NO_BACKGROUND:
+		gtk_widget_modify_style (GTK_WIDGET (eyes_applet->applet), rc_style);
+		break;
+
 	default:
-                for (i = 0; i < eyes_applet->num_eyes; i++) {
-                	gtk_widget_modify_style (eyes_applet->eyes[i], rc_style);
-        	}
+		gtk_widget_modify_style (GTK_WIDGET (eyes_applet->applet), rc_style);
 		break;
 	}
-	gtk_rc_style_unref (rc_style);
-	return;
-}
 
+	gtk_rc_style_unref (rc_style);
+}
 
 /* TODO - Optimize this a bit */
 static void 
@@ -211,7 +182,6 @@ about_cb (BonoboUIComponent *uic,
 	  EyesApplet        *eyes_applet,
 	  const gchar       *verbname)
 {
-	static GtkWidget *about = NULL;
 	GdkPixbuf	 *pixbuf;
 	GError		 *error = NULL;
 	gchar		 *file;
@@ -222,16 +192,19 @@ about_cb (BonoboUIComponent *uic,
 	};
 
 	const gchar *documenters[] = {
+                "Arjan Scherpenisse <acscherp@wins.uva.nl>",
+                "Telsa Gwynne <hobbit@aloss.ukuu.org.uk>",
+                "Sun GNOME Documentation Team <gdocteam@sun.com>",
 		NULL
 	};
 
 	const gchar *translator_credits = _("translator_credits");
 
-	if (about) {
-		gtk_window_set_screen (
-			GTK_WINDOW (about),
-			gtk_widget_get_screen (GTK_WIDGET (eyes_applet->applet)));
-		gtk_window_present (GTK_WINDOW (about));
+	if (eyes_applet->about_dialog) {
+		gtk_window_set_screen (GTK_WINDOW (eyes_applet->about_dialog),
+				       gtk_widget_get_screen (GTK_WIDGET (eyes_applet->applet)));
+		
+		gtk_window_present (GTK_WINDOW (eyes_applet->about_dialog));
 		return;
 	}
         
@@ -244,7 +217,7 @@ about_cb (BonoboUIComponent *uic,
 		g_error_free (error);
 	}
 	
-        about = gnome_about_new (
+        eyes_applet->about_dialog = gnome_about_new (
 		_("Geyes"), VERSION,
 		_("Copyright (C) 1999 Dave Camp"),
 		_("A goofy little xeyes clone for the GNOME panel."),
@@ -256,16 +229,16 @@ about_cb (BonoboUIComponent *uic,
 	if (pixbuf)
 		gdk_pixbuf_unref (pixbuf);
 			
-	gtk_window_set_wmclass (GTK_WINDOW (about), "geyes", "Geyes");
-	gtk_window_set_screen (GTK_WINDOW (about),
+	gtk_window_set_wmclass (GTK_WINDOW (eyes_applet->about_dialog), "geyes", "Geyes");
+	gtk_window_set_screen (GTK_WINDOW (eyes_applet->about_dialog),
 			       gtk_widget_get_screen (GTK_WIDGET (eyes_applet->applet)));
-	g_signal_connect (about, "destroy",
+	g_signal_connect (eyes_applet->about_dialog, "destroy",
 			  G_CALLBACK (gtk_widget_destroyed),
-			  &about);
-        gtk_widget_show (about);
+			  &eyes_applet->about_dialog);
+	gtk_widget_show (eyes_applet->about_dialog);
 }
 
-static void
+static int
 properties_load (EyesApplet *eyes_applet)
 {
         gchar *theme_path = NULL;
@@ -276,9 +249,15 @@ properties_load (EyesApplet *eyes_applet)
 	if (theme_path == NULL)
 		theme_path = g_strdup (GEYES_THEMES_DIR "Default-tiny");
 	
-        load_theme (eyes_applet, theme_path);
+        if (load_theme (eyes_applet, theme_path) == FALSE) {
+		g_free (theme_path);
+
+		return FALSE;
+	}
 
         g_free (theme_path);
+	
+	return TRUE;
 }
 
 void
@@ -289,6 +268,8 @@ setup_eyes (EyesApplet *eyes_applet)
         eyes_applet->hbox = gtk_hbox_new (FALSE, 0);
         gtk_box_pack_start (GTK_BOX (eyes_applet->vbox), eyes_applet->hbox, TRUE, TRUE, 0);
 
+	eyes_applet->eyes = g_new0 (GtkWidget *, eyes_applet->num_eyes);
+
         for (i = 0; i < eyes_applet->num_eyes; i++) {
                 eyes_applet->eyes[i] = gtk_image_new ();
                 if (eyes_applet->eyes[i] == NULL)
@@ -330,6 +311,8 @@ destroy_eyes (EyesApplet *eyes_applet)
 {
 	gtk_widget_destroy (eyes_applet->hbox);
 	eyes_applet->hbox = NULL;
+
+	g_free (eyes_applet->eyes);
 }
 
 static EyesApplet *
@@ -342,10 +325,6 @@ create_eyes (PanelApplet *applet)
 
 	gtk_container_add (GTK_CONTAINER (applet), eyes_applet->vbox);
 
-        properties_load (eyes_applet);
-
-        setup_eyes (eyes_applet);
-
 	return eyes_applet;
 }
 
@@ -355,6 +334,8 @@ destroy_cb (GtkObject *object, EyesApplet *eyes_applet)
 	g_return_if_fail (eyes_applet);
 
 	gtk_timeout_remove (eyes_applet->timeout_id);
+	if (eyes_applet->hbox)
+		destroy_eyes (eyes_applet);
 	if (eyes_applet->tooltips)
 		g_object_unref (eyes_applet->tooltips);
 	eyes_applet->timeout_id = 0;
@@ -377,8 +358,11 @@ destroy_cb (GtkObject *object, EyesApplet *eyes_applet)
 		g_free (eyes_applet->pupil_filename);
 	eyes_applet->pupil_filename = NULL;
 	
+	if (eyes_applet->about_dialog)
+	  	gtk_widget_destroy (eyes_applet->about_dialog);
+
 	if (eyes_applet->prop_box.pbox)
-	  gtk_widget_destroy (eyes_applet->prop_box.pbox);
+	  	gtk_widget_destroy (eyes_applet->prop_box.pbox);
 
 	g_free (eyes_applet);
 }
@@ -390,7 +374,7 @@ help_cb (BonoboUIComponent *uic,
 {
 	GError *error = NULL;
 
-	egg_help_display_on_screen (
+	gnome_help_display_on_screen (
 		"geyes", NULL,
 		gtk_widget_get_screen (GTK_WIDGET (eyes_applet->applet)),
 		&error);
@@ -431,13 +415,15 @@ geyes_applet_fill (PanelApplet *applet)
 {
 	EyesApplet *eyes_applet;
 	
-	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-eyes.png");
+	gtk_window_set_default_icon_name ("gnome-eyes");
 	panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
 	
         eyes_applet = create_eyes (applet);
 
 	panel_applet_add_preferences (applet, "/schemas/apps/geyes/prefs", NULL);
 
+	eyes_applet->about_dialog = NULL;
+
         eyes_applet->timeout_id = gtk_timeout_add (
 		UPDATE_TIMEOUT, (GtkFunction) timer_cb, eyes_applet);
 			
@@ -448,6 +434,17 @@ geyes_applet_fill (PanelApplet *applet)
 				           geyes_applet_menu_verbs,
 				           eyes_applet);
 
+	if (panel_applet_get_locked_down (eyes_applet->applet)) {
+		BonoboUIComponent *popup_component;
+
+		popup_component = panel_applet_get_popup_component (eyes_applet->applet);
+
+		bonobo_ui_component_set_prop (popup_component,
+					      "/commands/Props",
+					      "hidden", "1",
+					      NULL);
+	}
+
 	eyes_applet->tooltips = gtk_tooltips_new ();
 	g_object_ref (eyes_applet->tooltips);
 	gtk_object_sink (GTK_OBJECT (eyes_applet->tooltips));
@@ -456,8 +453,6 @@ geyes_applet_fill (PanelApplet *applet)
 	set_atk_name_description (GTK_WIDGET (eyes_applet->applet), _("Geyes"), 
 			_("The eyes look in the direction of the mouse pointer"));
 
-	gtk_widget_show_all (GTK_WIDGET (eyes_applet->applet));
-
 	g_signal_connect (eyes_applet->applet,
 			  "change_background",
 			  G_CALLBACK (applet_back_change),
@@ -466,9 +461,18 @@ geyes_applet_fill (PanelApplet *applet)
 			  "destroy",
 			  G_CALLBACK (destroy_cb),
 			  eyes_applet);
-	  
+
+	gtk_widget_show_all (GTK_WIDGET (eyes_applet->applet));
+
+	/* setup here and not in create eyes so the destroy signal is set so 
+	 * that when there is an error within loading the theme
+	 * we can emit this signal */
+        if (properties_load (eyes_applet) == FALSE)
+		return FALSE;
+
+	setup_eyes (eyes_applet);
+
 	return TRUE;
-	
 }
 
 static gboolean
@@ -477,10 +481,16 @@ geyes_applet_factory (PanelApplet *applet,
 		      gpointer     data)
 {
 	gboolean retval = FALSE;
-    
+
+	theme_dirs_create ();
+
 	if (!strcmp (iid, "OAFIID:GNOME_GeyesApplet"))
 		retval = geyes_applet_fill (applet); 
-    
+   
+	if (retval == FALSE) {
+		exit (-1);
+	}
+
 	return retval;
 }
 
