@@ -26,7 +26,7 @@
 
 #include <gconf/gconf-client.h>
 #include <panel-applet-gconf.h>
-#include <egg-screen-help.h>
+#include <libgnomeui/gnome-help.h>
 #include "geyes.h"
 
 #define NUM_THEME_DIRECTORIES 2
@@ -35,9 +35,9 @@
 gchar *theme_directories[NUM_THEME_DIRECTORIES];
 
 void
-theme_dirs_create ()
+theme_dirs_create (void)
 {
-	static themes_created = FALSE;
+	static gboolean themes_created = FALSE;
 	
 	if (themes_created == TRUE)
 		return;
@@ -69,6 +69,8 @@ parse_theme_file (EyesApplet *eyes_applet, FILE *theme_file)
                                 token++;
                         }
                         sscanf (token, "%d", &eyes_applet->num_eyes);
+			if (eyes_applet->num_eyes > MAX_EYES)
+				eyes_applet->num_eyes = MAX_EYES;
                 } else if (strncmp (token, "eye-pixmap", strlen ("eye-pixmap")) == 0) {
                         token = strtok (NULL, "\"");
                         token = strtok (NULL, "\"");          
@@ -228,7 +230,7 @@ phelp_cb (GtkDialog *dialog)
 {
 	GError *error = NULL;
 
-	egg_help_display_on_screen (
+	gnome_help_display_on_screen (
 		"geyes", "geyes-settings",
 		gtk_window_get_screen (GTK_WINDOW (dialog)),
 		&error);
@@ -265,6 +267,7 @@ properties_cb (BonoboUIComponent *uic,
 	GtkWidget *categories_vbox;
 	GtkWidget *category_vbox, *control_vbox;
         GtkWidget *tree;
+	GtkWidget *scrolled;
         GtkWidget *label;
         GtkListStore *model;
         GtkTreeViewColumn *column;
@@ -294,9 +297,12 @@ properties_cb (BonoboUIComponent *uic,
 					     GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 					     GTK_STOCK_HELP, GTK_RESPONSE_HELP,
 					     NULL);
+
 	gtk_window_set_screen (GTK_WINDOW (pbox),
 			       gtk_widget_get_screen (GTK_WIDGET (eyes_applet->applet)));
-        gtk_window_set_resizable (GTK_WINDOW (pbox), FALSE);
+        
+	gtk_widget_set_size_request (GTK_WIDGET (pbox), 300, 200);
+	gtk_window_set_resizable (GTK_WINDOW (pbox), FALSE);
         gtk_dialog_set_default_response(GTK_DIALOG (pbox), GTK_RESPONSE_CLOSE);
         gtk_dialog_set_has_separator (GTK_DIALOG (pbox), FALSE);
         gtk_container_set_border_width (GTK_CONTAINER (pbox), 5);
@@ -345,12 +351,20 @@ properties_cb (BonoboUIComponent *uic,
 	label = gtk_label_new_with_mnemonic (_("_Select a theme:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 	gtk_box_pack_start (GTK_BOX (control_vbox), label, FALSE, FALSE, 0);
-	
+
+	scrolled = gtk_scrolled_window_new (NULL, NULL);
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled), GTK_SHADOW_IN);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled),
+					GTK_POLICY_AUTOMATIC,
+					GTK_POLICY_AUTOMATIC);
+
 	model = gtk_list_store_new (1, G_TYPE_STRING);
 	tree = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (tree), FALSE);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), tree);
 	g_object_unref (model);
+
+	gtk_container_add (GTK_CONTAINER (scrolled), tree);
 	
 	cell = gtk_cell_renderer_text_new ();
 	column = gtk_tree_view_column_new_with_attributes ("not used", cell,
@@ -405,7 +419,7 @@ properties_cb (BonoboUIComponent *uic,
 	g_free (filename);
 #endif
         
-        gtk_box_pack_start (GTK_BOX (control_vbox), tree, TRUE, TRUE, 0);
+        gtk_box_pack_start (GTK_BOX (control_vbox), scrolled, TRUE, TRUE, 0);
         
         gtk_widget_show_all (pbox);
         
