@@ -706,8 +706,7 @@ static gint updateOutput(gpointer data)
 			      StockData         *stockdata, 
 			      const gchar       *verbname) {
 		GdkPixbuf *pixbuf;
-		GError    *error = NULL;
-		gchar     *file;
+
 		static const gchar *authors[] = {
 			"Jayson Lorenzen <jayson_lorenzen@yahoo.com>",
 			"Jim Garrison <garrison@users.sourceforge.net>",
@@ -730,19 +729,10 @@ static gint updateOutput(gpointer data)
 			return;
 		}
 
-		file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP,
-			"gnome-money.png", FALSE, NULL);
-		
-		pixbuf = gdk_pixbuf_new_from_file (file, &error);
-		
-		g_free (file);
-		
-		if (error) {
-			g_warning (G_STRLOC ": cannot open %s: %s", file, error->message);
-			
-			g_error_free (error);
-		}
-		
+		pixbuf = gtk_icon_theme_load_icon (
+				gtk_icon_theme_get_default (),
+				"gnome-money", 48, 0, NULL);
+
 		stockdata->about_dialog = gnome_about_new (_("Stock Ticker"), VERSION,
 		"(C) 2000 Jayson Lorenzen, Jim Garrison, Rached Blili",
 		_("This program connects to "
@@ -1765,7 +1755,7 @@ static gint updateOutput(gpointer data)
 
 		gnome_vfs_init();
 		
-		gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-money.png");
+		gtk_window_set_default_icon_name ("gnome-money");
 		panel_applet_add_preferences (applet, "/schemas/apps/gtik/prefs", NULL);
 		panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
 		
@@ -1986,49 +1976,33 @@ static gint updateOutput(gpointer data)
 	}
 
 	/*-----------------------------------------------------------------*/
-	char *splitChange(StockData *stockdata,char *data, StockQuote *quote) {
-		char buff[MAX_SYMBOL_LEN]; 
-		static char buff2[MAX_SYMBOL_LEN];
+	char *splitChange(StockData *stockdata, char *data, StockQuote *quote) {
+		char *buff, *buff2;
 		char *var1, *var2, *var3, *var4;
-		char rise[2]; 
 
-                bzero(buff, MAX_SYMBOL_LEN); 
-                bzero(buff2, MAX_SYMBOL_LEN); 
-                bzero(rise, 2); 
-                
-		strcpy(buff,data);
+		buff = g_strdup (data);
 		var1 = strtok(buff,":");
 		var2 = strtok(NULL,":");
 		var3 = strtok(NULL,":");
 		var4 = strtok(NULL,"");
+		g_free (buff);
 
 		if (!var3 || !var4)
 			return NULL;
 
 		if (var4[0] == '+') { 
-#if 0
-			if (stockdata->symbolfont)
-				var3[0] = 221;
-#endif
-			var4[0] = '(';
 			quote->color = GREEN;
-			sprintf (rise, "+");
+			buff2 = g_strdup_printf (_("+%s (%s)"), var3, &var4[1]);
 		}
 		else if (var4[0] == '-') {
-#if 0
-			if (stockdata->symbolfont)
-				var3[0] = 223;	
-#endif
-			var4[0] = '(';
 			quote->color = RED;
+			buff2 = g_strdup_printf (_("%s (%s)"), var3, &var4[1]);
 		}
 		else {
-			var3 = g_strdup(_("(No Change"));
-			var4 = g_strdup("");
+			buff2 = g_strdup(_("(No Change)"));
 			quote->color = WHITE;
 		}
 
-		sprintf(buff2,"%s%s %s)",rise, var3,var4);
 		return(buff2);
 	}
 
@@ -2059,6 +2033,7 @@ static gint updateOutput(gpointer data)
 			quote.changelen = 0;
 			quote.changeheight = 0;
 		}
+		g_free (change);
 		 
 
 #if 0
