@@ -1,4 +1,4 @@
-/* $Id: gweather-dialog.c,v 1.44 2004/06/26 12:18:43 dsmit Exp $ */
+/* $Id: gweather-dialog.c,v 1.48 2004/11/29 03:48:21 davyd Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -26,6 +26,77 @@
 #include "gweather-pref.h"
 #include "gweather-dialog.h"
 
+static void gweather_dialog_save_geometry (GWeatherApplet *gw_applet)
+{
+	GtkWidget *window;
+	int w, h, x, y;
+
+	window = gw_applet->gweather_dialog;
+
+	gtk_window_get_position (GTK_WINDOW (window), &x, &y);
+	gtk_window_get_size (GTK_WINDOW (window), &w, &h);
+
+	g_message ("gweather: saving spatial window location: %dx%d+%d+%d",
+			w, h, x, y);
+
+	panel_applet_gconf_set_int (gw_applet->applet,
+			"dialog_width", w, NULL);
+	panel_applet_gconf_set_int (gw_applet->applet,
+			"dialog_height", h, NULL);
+	panel_applet_gconf_set_int (gw_applet->applet,
+			"dialog_x", x, NULL);
+	panel_applet_gconf_set_int (gw_applet->applet,
+			"dialog_y", y, NULL);
+}
+
+static void gweather_dialog_load_geometry (GWeatherApplet *gw_applet)
+{
+	GtkWidget *window;
+	int w, h, x, y;
+	GError *error;
+
+	window = gw_applet->gweather_dialog;
+	error = NULL;
+
+	w = panel_applet_gconf_get_int (gw_applet->applet,
+			"dialog_width", &error);
+	if (error)
+	{
+		g_message ("gweather: no spatial information available");
+		g_error_free (error);
+		return;
+	}
+	h = panel_applet_gconf_get_int (gw_applet->applet,
+			"dialog_height", &error);
+	if (error)
+	{
+		g_message ("gweather: no spatial information available");
+		g_error_free (error);
+		return;
+	}
+	x = panel_applet_gconf_get_int (gw_applet->applet,
+			"dialog_x", &error);
+	if (error)
+	{
+		g_message ("gweather: no spatial information available");
+		g_error_free (error);
+		return;
+	}
+	y = panel_applet_gconf_get_int (gw_applet->applet,
+			"dialog_y", &error);
+	if (error)
+	{
+		g_message ("gweather: no spatial information available");
+		g_error_free (error);
+		return;
+	}
+	
+	g_message ("gweather: got spatial window location: %dx%d+%d+%d",
+			w, h, x, y);
+
+	gtk_window_resize (GTK_WINDOW (window), w, h);
+	gtk_window_move (GTK_WINDOW (window), x, y);
+}
 
 static void response_cb (GtkDialog *dialog, gint id, gpointer data)
 {
@@ -38,7 +109,7 @@ static void response_cb (GtkDialog *dialog, gint id, gpointer data)
 
 	return;
     }
-    
+
     gweather_dialog_close(gw_applet);
     return;
 }
@@ -68,6 +139,8 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   GtkWidget *cond_vis_lbl;
   GtkWidget *cond_dew_lbl;
   GtkWidget *cond_apparent_lbl;
+  GtkWidget *cond_sunrise_lbl;
+  GtkWidget *cond_sunset_lbl;
   GtkWidget *cond_frame_alignment;
   GtkWidget *current_note_lbl;
   GtkWidget *forecast_note_lbl;
@@ -80,7 +153,7 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   GtkWidget *scrolled_window;
   GtkWidget *imagescroll_window;
 
-  gw_applet->gweather_dialog = gtk_dialog_new_with_buttons (_("Forecast"), NULL,
+  gw_applet->gweather_dialog = gtk_dialog_new_with_buttons (_("Details"), NULL,
 						  GTK_DIALOG_DESTROY_WITH_PARENT,
 						  _("_Update"),
 						  GTK_RESPONSE_OK,
@@ -99,6 +172,7 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   gtk_window_set_screen (GTK_WINDOW (gw_applet->gweather_dialog),
 			 gtk_widget_get_screen (GTK_WIDGET (gw_applet->applet)));
   gtk_window_set_policy (GTK_WINDOW (gw_applet->gweather_dialog), FALSE, FALSE, FALSE);
+  gweather_dialog_load_geometry (gw_applet);
   
   weather_vbox = GTK_DIALOG (gw_applet->gweather_dialog)->vbox;
   gtk_widget_show (weather_vbox);
@@ -113,7 +187,7 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   gtk_container_add (GTK_CONTAINER (weather_notebook), cond_hbox);
   gtk_container_set_border_width (GTK_CONTAINER (cond_hbox), 4);
 
-  cond_table = gtk_table_new (11, 2, FALSE);
+  cond_table = gtk_table_new (13, 2, FALSE);
   gtk_widget_show (cond_table);
   gtk_box_pack_start (GTK_BOX (cond_hbox), cond_table, TRUE, TRUE, 0);
   gtk_container_set_border_width (GTK_CONTAINER (cond_table), 12);
@@ -176,7 +250,7 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   gtk_label_set_justify (GTK_LABEL (cond_dew_lbl), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (cond_dew_lbl), 0, 0.5);
 
-  cond_humidity_lbl = gtk_label_new (_("Humidity:"));
+  cond_humidity_lbl = gtk_label_new (_("Relative humidity:"));
   gtk_widget_show (cond_humidity_lbl);
   gtk_table_attach (GTK_TABLE (cond_table), cond_humidity_lbl, 0, 1, 7, 8,
                     (GtkAttachOptions) (GTK_FILL),
@@ -208,11 +282,28 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   gtk_label_set_justify (GTK_LABEL (cond_vis_lbl), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (cond_vis_lbl), 0, 0.5);
 
+  cond_sunrise_lbl = gtk_label_new (_("Sunrise:"));
+  gtk_widget_show (cond_sunrise_lbl);
+  gtk_table_attach (GTK_TABLE (cond_table), cond_sunrise_lbl, 0, 1, 11, 12,
+                    (GtkAttachOptions) (GTK_FILL),
+                    (GtkAttachOptions) (0), 0, 0);
+  gtk_label_set_justify (GTK_LABEL (cond_sunrise_lbl), GTK_JUSTIFY_LEFT);
+  gtk_misc_set_alignment (GTK_MISC (cond_sunrise_lbl), 0, 0.5);
+
+  cond_sunset_lbl = gtk_label_new (_("Sunset:"));
+  gtk_widget_show (cond_sunset_lbl);
+  gtk_table_attach (GTK_TABLE (cond_table), cond_sunset_lbl, 0, 1, 12, 13,
+                    (GtkAttachOptions) (GTK_FILL),
+                    (GtkAttachOptions) (0), 0, 0);
+  gtk_label_set_justify (GTK_LABEL (cond_sunset_lbl), GTK_JUSTIFY_LEFT);
+  gtk_misc_set_alignment (GTK_MISC (cond_sunset_lbl), 0, 0.5);
+
   gw_applet->cond_location = gtk_label_new ("");
   gtk_widget_show (gw_applet->cond_location);
   gtk_table_attach (GTK_TABLE (cond_table), gw_applet->cond_location, 1, 2, 0, 1,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
+  gtk_label_set_selectable (GTK_LABEL (gw_applet->cond_location), TRUE);
   gtk_label_set_justify (GTK_LABEL (gw_applet->cond_location), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (gw_applet->cond_location), 0, 0.5);
 
@@ -221,6 +312,7 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   gtk_table_attach (GTK_TABLE (cond_table), gw_applet->cond_update, 1, 2, 1, 2,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
+  gtk_label_set_selectable (GTK_LABEL (gw_applet->cond_update), TRUE);
   gtk_label_set_justify (GTK_LABEL (gw_applet->cond_update), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (gw_applet->cond_update), 0, 0.5);
 
@@ -229,6 +321,7 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   gtk_table_attach (GTK_TABLE (cond_table), gw_applet->cond_cond, 1, 2, 2, 3,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
+  gtk_label_set_selectable (GTK_LABEL (gw_applet->cond_cond), TRUE);
   gtk_label_set_justify (GTK_LABEL (gw_applet->cond_cond), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (gw_applet->cond_cond), 0, 0.5);
 
@@ -237,6 +330,7 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   gtk_table_attach (GTK_TABLE (cond_table), gw_applet->cond_sky, 1, 2, 3, 4,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
+  gtk_label_set_selectable (GTK_LABEL (gw_applet->cond_sky), TRUE);
   gtk_label_set_justify (GTK_LABEL (gw_applet->cond_sky), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (gw_applet->cond_sky), 0, 0.5);
 
@@ -245,6 +339,7 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   gtk_table_attach (GTK_TABLE (cond_table), gw_applet->cond_temp, 1, 2, 4, 5,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
+  gtk_label_set_selectable (GTK_LABEL (gw_applet->cond_temp), TRUE);
   gtk_label_set_justify (GTK_LABEL (gw_applet->cond_temp), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (gw_applet->cond_temp), 0, 0.5);
 
@@ -253,6 +348,7 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   gtk_table_attach (GTK_TABLE (cond_table), gw_applet->cond_apparent, 1, 2, 5, 6,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
+  gtk_label_set_selectable (GTK_LABEL (gw_applet->cond_apparent), TRUE);
   gtk_label_set_justify (GTK_LABEL (gw_applet->cond_apparent), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (gw_applet->cond_apparent), 0, 0.5);
 
@@ -261,6 +357,7 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   gtk_table_attach (GTK_TABLE (cond_table), gw_applet->cond_dew, 1, 2, 6, 7,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
+  gtk_label_set_selectable (GTK_LABEL (gw_applet->cond_dew), TRUE);
   gtk_label_set_justify (GTK_LABEL (gw_applet->cond_dew), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (gw_applet->cond_dew), 0, 0.5);
 
@@ -269,6 +366,7 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   gtk_table_attach (GTK_TABLE (cond_table), gw_applet->cond_humidity, 1, 2, 7, 8,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
+  gtk_label_set_selectable (GTK_LABEL (gw_applet->cond_humidity), TRUE);
   gtk_label_set_justify (GTK_LABEL (gw_applet->cond_humidity), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (gw_applet->cond_humidity), 0, 0.5);
 
@@ -277,6 +375,7 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   gtk_table_attach (GTK_TABLE (cond_table), gw_applet->cond_wind, 1, 2, 8, 9,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
+  gtk_label_set_selectable (GTK_LABEL (gw_applet->cond_wind), TRUE);
   gtk_label_set_justify (GTK_LABEL (gw_applet->cond_wind), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (gw_applet->cond_wind), 0, 0.5);
 
@@ -285,6 +384,7 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   gtk_table_attach (GTK_TABLE (cond_table), gw_applet->cond_pressure, 1, 2, 9, 10,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
+  gtk_label_set_selectable (GTK_LABEL (gw_applet->cond_pressure), TRUE);
   gtk_label_set_justify (GTK_LABEL (gw_applet->cond_pressure), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (gw_applet->cond_pressure), 0, 0.5);
 
@@ -293,9 +393,28 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   gtk_table_attach (GTK_TABLE (cond_table), gw_applet->cond_vis, 1, 2, 10, 11,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
+  gtk_label_set_selectable (GTK_LABEL (gw_applet->cond_vis), TRUE);
   gtk_label_set_justify (GTK_LABEL (gw_applet->cond_vis), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (gw_applet->cond_vis), 0, 0.5);
 
+  gw_applet->cond_sunrise = gtk_label_new ("");
+  gtk_widget_show (gw_applet->cond_sunrise);
+  gtk_table_attach (GTK_TABLE (cond_table), gw_applet->cond_sunrise, 1, 2, 11, 12,
+                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+                    (GtkAttachOptions) (0), 0, 0);
+  gtk_label_set_selectable (GTK_LABEL (gw_applet->cond_sunrise), TRUE);
+  gtk_label_set_justify (GTK_LABEL (gw_applet->cond_sunrise), GTK_JUSTIFY_LEFT);
+  gtk_misc_set_alignment (GTK_MISC (gw_applet->cond_sunrise), 0, 0.5);
+
+  gw_applet->cond_sunset = gtk_label_new ("");
+  gtk_widget_show (gw_applet->cond_sunset);
+  gtk_table_attach (GTK_TABLE (cond_table), gw_applet->cond_sunset, 1, 2, 12, 13,
+                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+                    (GtkAttachOptions) (0), 0, 0);
+  gtk_label_set_selectable (GTK_LABEL (gw_applet->cond_sunset), TRUE);
+  gtk_label_set_justify (GTK_LABEL (gw_applet->cond_sunset), GTK_JUSTIFY_LEFT);
+  gtk_misc_set_alignment (GTK_MISC (gw_applet->cond_sunset), 0, 0.5);
+
   cond_frame_alignment = gtk_alignment_new (0.5, 0, 1, 0);
   gtk_widget_show (cond_frame_alignment);
   gtk_box_pack_end (GTK_BOX (cond_hbox), cond_frame_alignment, FALSE, FALSE, 0);
@@ -409,6 +528,8 @@ void gweather_dialog_open (GWeatherApplet *gw_applet)
 
 void gweather_dialog_close (GWeatherApplet *gw_applet)
 {
+    gweather_dialog_save_geometry (gw_applet);
+    
     g_return_if_fail(gw_applet->gweather_dialog != NULL);
     gtk_widget_destroy(gw_applet->gweather_dialog);
     gw_applet->gweather_dialog = NULL;
@@ -454,6 +575,8 @@ void gweather_dialog_update (GWeatherApplet *gw_applet)
     gtk_label_set_text(GTK_LABEL(gw_applet->cond_wind), weather_info_get_wind(gw_applet->gweather_info));
     gtk_label_set_text(GTK_LABEL(gw_applet->cond_pressure), weather_info_get_pressure(gw_applet->gweather_info));
     gtk_label_set_text(GTK_LABEL(gw_applet->cond_vis), weather_info_get_visibility(gw_applet->gweather_info));
+    gtk_label_set_text(GTK_LABEL(gw_applet->cond_sunrise), weather_info_get_sunrise(gw_applet->gweather_info));
+    gtk_label_set_text(GTK_LABEL(gw_applet->cond_sunset), weather_info_get_sunset(gw_applet->gweather_info));
 
     /* Update forecast */
     if (gw_applet->gweather_pref.location->zone_valid) {
