@@ -52,10 +52,9 @@ static const char GSWITCHIT_CONFIG_APPLET_KEY_ENABLED_PLUGINS[] =
     GSWITCHIT_CONFIG_APPLET_PREFIX "/enabledPlugins";
 
 static int gconfAppletListenerId = 0;
-static int gconfImagesListenerId = 0;
-static int gconfCommandsListenerId = 0;
 
-#define GSWITCHIT_CONFIG_XKB_KEY_PREFIX "/desktop/gnome/peripherals/keyboard/xkb"
+#define KEYBOARD_CONFIG_KEY_PREFIX "/desktop/gnome/peripherals/keyboard"
+#define GSWITCHIT_CONFIG_XKB_KEY_PREFIX KEYBOARD_CONFIG_KEY_PREFIX "/xkb"
 
 const char GSWITCHIT_CONFIG_XKB_DIR[] = GSWITCHIT_CONFIG_XKB_KEY_PREFIX;
 const char GSWITCHIT_CONFIG_XKB_KEY_OVERRIDE_SETTINGS[] =
@@ -67,6 +66,29 @@ const char GSWITCHIT_CONFIG_XKB_KEY_LAYOUTS[] =
 const char GSWITCHIT_CONFIG_XKB_KEY_OPTIONS[] =
     GSWITCHIT_CONFIG_XKB_KEY_PREFIX "/options";
 
+const char *GSWITCHIT_CONFIG_XKB_ACTIVE[] = {
+	GSWITCHIT_CONFIG_XKB_KEY_MODEL,
+	GSWITCHIT_CONFIG_XKB_KEY_LAYOUTS,
+	GSWITCHIT_CONFIG_XKB_KEY_OPTIONS
+};
+
+#define GSWITCHIT_CONFIG_XKB_SYSBACKUP_KEY_PREFIX KEYBOARD_CONFIG_KEY_PREFIX "/xkb.sysbackup"
+
+const char GSWITCHIT_CONFIG_XKB_SYSBACKUP_DIR[] =
+    GSWITCHIT_CONFIG_XKB_SYSBACKUP_KEY_PREFIX;
+const char GSWITCHIT_CONFIG_XKB_SYSBACKUP_KEY_MODEL[] =
+    GSWITCHIT_CONFIG_XKB_SYSBACKUP_KEY_PREFIX "/model";
+const char GSWITCHIT_CONFIG_XKB_SYSBACKUP_KEY_LAYOUTS[] =
+    GSWITCHIT_CONFIG_XKB_SYSBACKUP_KEY_PREFIX "/layouts";
+const char GSWITCHIT_CONFIG_XKB_SYSBACKUP_KEY_OPTIONS[] =
+    GSWITCHIT_CONFIG_XKB_SYSBACKUP_KEY_PREFIX "/options";
+
+const char *GSWITCHIT_CONFIG_XKB_SYSBACKUP[] = {
+	GSWITCHIT_CONFIG_XKB_SYSBACKUP_KEY_MODEL,
+	GSWITCHIT_CONFIG_XKB_SYSBACKUP_KEY_LAYOUTS,
+	GSWITCHIT_CONFIG_XKB_SYSBACKUP_KEY_OPTIONS
+};
+
 static int gconfXkbListenerId;
 
 /**
@@ -357,44 +379,6 @@ _GSwitchItXkbConfigCopyToXklConfig (GSwitchItXkbConfig *
 	}
 }
 
-static gboolean
-_GSwitchItXkbConfigDoWithSettings (GSwitchItXkbConfig *
-				   xkbConfig,
-				   gboolean activate,
-				   const char *psFileName)
-{
-	gboolean rv = FALSE;
-
-	XklConfigRec data;
-	XklConfigRecInit (&data);
-
-	_GSwitchItXkbConfigCopyToXklConfig (xkbConfig, &data);
-
-	if (activate) {
-		rv = XklConfigActivate (&data, NULL);
-	} else {
-		char *home = getenv ("HOME");
-		char xkmFileName[PATH_MAX];
-		char cmd[PATH_MAX * 2 + 20];
-		int status;
-		g_snprintf (xkmFileName, sizeof (xkmFileName),
-			    "%s/.gnome_private/xkbpreview.xkm", home);
-		rv = XklConfigWriteXKMFile (xkmFileName, &data, NULL);
-		if (rv) {
-			g_snprintf (cmd, sizeof (cmd),
-				    "xkbprint -full -color %s %s",
-				    xkmFileName, psFileName);
-			status = system (cmd);
-			XklDebug (100, "Res: [%d]\n", status);
-			//unlink( xkmFileName );
-		} else {
-			XklDebug (10, "Could not create XKM file!\n");
-		}
-	}
-	XklConfigRecDestroy (&data);
-	return rv;
-}
-
 static gboolean
 _GSListStrEqual (GSList * l1, GSList * l2)
 {
@@ -413,6 +397,99 @@ _GSListStrEqual (GSList * l1, GSList * l2)
 	return (l1 == NULL && l2 == NULL);
 }
 
+static void
+_GSwitchItXkbConfigLoadParams (GSwitchItXkbConfig * xkbConfig,
+			       const char *paramNames[])
+{
+	GError *gerror = NULL;
+	gchar *pc;
+	GSList *pl;
+
+	pc = gconf_client_get_string (xkbConfig->confClient,
+				      paramNames[0], &gerror);
+	if (pc == NULL || gerror != NULL) {
+		if (gerror != NULL) {
+			g_warning ("Error reading configuration:%s\n",
+				   gerror->message);
+			g_error_free (gerror);
+			gerror = NULL;
+		}
+		GSwitchItXkbConfigModelSet (xkbConfig, NULL);
+	} else {
+		GSwitchItXkbConfigModelSet (xkbConfig, pc);
+	}
+	XklDebug (150, "Loaded XKB model: [%s]\n", xkbConfig->model);
+
+	GSwitchItXkbConfigLayoutsReset (xkbConfig);
+
+	pl = gconf_client_get_list (xkbConfig->confClient,
+				    paramNames[1],
+				    GCONF_VALUE_STRING, &gerror);
+	if (pl == NULL || gerror != NULL) {
+		if (gerror != NULL) {
+			g_warning ("Error reading configuration:%s\n",
+				   gerror->message);
+			g_error_free (gerror);
+			gerror = NULL;
+		}
+	}
+
+	while (pl != NULL) {
+		XklDebug (150, "Loaded XKB layout: [%s]\n", pl->data);
+		_GSwitchItXkbConfigLayoutsAdd (xkbConfig, pl->data);
+		pl = pl->next;
+	}
+
+	GSwitchItXkbConfigOptionsReset (xkbConfig);
+
+	pl = gconf_client_get_list (xkbConfig->confClient,
+				    paramNames[2],
+				    GCONF_VALUE_STRING, &gerror);
+	if (pl == NULL || gerror != NULL) {
+		if (gerror != NULL) {
+			g_warning ("Error reading configuration:%s\n",
+				   gerror->message);
+			g_error_free (gerror);
+			gerror = NULL;
+		}
+	}
+
+	while (pl != NULL) {
+		XklDebug (150, "Loaded XKB option: [%s]\n", pl->data);
+		_GSwitchItXkbConfigOptionsAdd (xkbConfig,
+					       (const char *) pl->data);
+		pl = pl->next;
+	}
+}
+
+static void
+_GSwitchItXkbConfigSaveParams (GSwitchItXkbConfig * xkbConfig,
+			       GConfChangeSet * cs,
+			       const char *paramNames[])
+{
+	GSList *pl;
+
+	gconf_change_set_set_string (cs, paramNames[0], xkbConfig->model);
+	XklDebug (150, "Saved XKB model: [%s]\n", xkbConfig->model);
+
+	pl = xkbConfig->layouts;
+	while (pl != NULL) {
+		XklDebug (150, "Saved XKB layout: [%s]\n", pl->data);
+		pl = pl->next;
+	}
+	gconf_change_set_set_list (cs,
+				   paramNames[1],
+				   GCONF_VALUE_STRING, xkbConfig->layouts);
+	pl = xkbConfig->options;
+	while (pl != NULL) {
+		XklDebug (150, "Saved XKB option: [%s]\n", pl->data);
+		pl = pl->next;
+	}
+	gconf_change_set_set_list (cs,
+				   paramNames[2],
+				   GCONF_VALUE_STRING, xkbConfig->options);
+}
+
 /**
  * extern xkb config functions
  */
@@ -451,8 +528,6 @@ void
 GSwitchItXkbConfigLoad (GSwitchItXkbConfig * xkbConfig)
 {
 	GError *gerror = NULL;
-	gchar *pc;
-	GSList *pl;
 
 	xkbConfig->overrideSettings =
 	    gconf_client_get_bool (xkbConfig->confClient,
@@ -468,62 +543,15 @@ GSwitchItXkbConfigLoad (GSwitchItXkbConfig * xkbConfig)
 	XklDebug (150, "Loaded XKB override cmd: [%s]\n",
 		  xkbConfig->overrideSettings ? "true" : "false");
 
-	pc = gconf_client_get_string (xkbConfig->confClient,
-				      GSWITCHIT_CONFIG_XKB_KEY_MODEL,
-				      &gerror);
-	if (pc == NULL || gerror != NULL) {
-		if (gerror != NULL) {
-			g_warning ("Error reading configuration:%s\n",
-				   gerror->message);
-			g_error_free (gerror);
-			gerror = NULL;
-		}
-		GSwitchItXkbConfigModelSet (xkbConfig, NULL);
-	} else {
-		GSwitchItXkbConfigModelSet (xkbConfig, pc);
-	}
-	XklDebug (150, "Loaded XKB model: [%s]\n", xkbConfig->model);
+	_GSwitchItXkbConfigLoadParams (xkbConfig,
+				       GSWITCHIT_CONFIG_XKB_ACTIVE);
+}
 
-	GSwitchItXkbConfigLayoutsReset (xkbConfig);
-
-	pl = gconf_client_get_list (xkbConfig->confClient,
-				    GSWITCHIT_CONFIG_XKB_KEY_LAYOUTS,
-				    GCONF_VALUE_STRING, &gerror);
-	if (pl == NULL || gerror != NULL) {
-		if (gerror != NULL) {
-			g_warning ("Error reading configuration:%s\n",
-				   gerror->message);
-			g_error_free (gerror);
-			gerror = NULL;
-		}
-	}
-
-	while (pl != NULL) {
-		XklDebug (150, "Loaded XKB layout: [%s]\n", pl->data);
-		_GSwitchItXkbConfigLayoutsAdd (xkbConfig, pl->data);
-		pl = pl->next;
-	}
-
-	GSwitchItXkbConfigOptionsReset (xkbConfig);
-
-	pl = gconf_client_get_list (xkbConfig->confClient,
-				    GSWITCHIT_CONFIG_XKB_KEY_OPTIONS,
-				    GCONF_VALUE_STRING, &gerror);
-	if (pl == NULL || gerror != NULL) {
-		if (gerror != NULL) {
-			g_warning ("Error reading configuration:%s\n",
-				   gerror->message);
-			g_error_free (gerror);
-			gerror = NULL;
-		}
-	}
-
-	while (pl != NULL) {
-		XklDebug (150, "Loaded XKB option: [%s]\n", pl->data);
-		_GSwitchItXkbConfigOptionsAdd (xkbConfig,
-					       (const char *) pl->data);
-		pl = pl->next;
-	}
+void
+GSwitchItXkbConfigLoadSysBackup (GSwitchItXkbConfig * xkbConfig)
+{
+	_GSwitchItXkbConfigLoadParams (xkbConfig,
+				       GSWITCHIT_CONFIG_XKB_SYSBACKUP);
 }
 
 void
@@ -574,7 +602,6 @@ GSwitchItXkbConfigSave (GSwitchItXkbConfig * xkbConfig)
 {
 	GConfChangeSet *cs;
 	GError *gerror = NULL;
-	GSList *pl;
 
 	cs = gconf_change_set_new ();
 	gconf_change_set_set_bool (cs,
@@ -583,31 +610,35 @@ GSwitchItXkbConfigSave (GSwitchItXkbConfig * xkbConfig)
 	XklDebug (150, "Saved XKB override cmd: [%s]\n",
 		  xkbConfig->overrideSettings ? "true" : "false");
 
-	gconf_change_set_set_string (cs, GSWITCHIT_CONFIG_XKB_KEY_MODEL,
-				     xkbConfig->model);
-	XklDebug (150, "Saved XKB model: [%s]\n", xkbConfig->model);
-
-	pl = xkbConfig->layouts;
-	while (pl != NULL) {
-		XklDebug (150, "Saved XKB layout: [%s]\n", pl->data);
-		pl = pl->next;
-	}
-	gconf_change_set_set_list (cs,
-				   GSWITCHIT_CONFIG_XKB_KEY_LAYOUTS,
-				   GCONF_VALUE_STRING, xkbConfig->layouts);
-	pl = xkbConfig->options;
-	while (pl != NULL) {
-		XklDebug (150, "Saved XKB option: [%s]\n", pl->data);
-		pl = pl->next;
-	}
-	gconf_change_set_set_list (cs,
-				   GSWITCHIT_CONFIG_XKB_KEY_OPTIONS,
-				   GCONF_VALUE_STRING, xkbConfig->options);
+	_GSwitchItXkbConfigSaveParams (xkbConfig, cs,
+				       GSWITCHIT_CONFIG_XKB_ACTIVE);
 
 	gconf_client_commit_change_set (xkbConfig->confClient, cs, TRUE,
 					&gerror);
 	if (gerror != NULL) {
-		g_warning ("Error saving configuration: %s\n",
+		g_warning ("Error saving active configuration: %s\n",
+			   gerror->message);
+		g_error_free (gerror);
+		gerror = NULL;
+	}
+	gconf_change_set_unref (cs);
+}
+
+void
+GSwitchItXkbConfigSaveSysBackup (GSwitchItXkbConfig * xkbConfig)
+{
+	GConfChangeSet *cs;
+	GError *gerror = NULL;
+
+	cs = gconf_change_set_new ();
+
+	_GSwitchItXkbConfigSaveParams (xkbConfig, cs,
+				       GSWITCHIT_CONFIG_XKB_SYSBACKUP);
+
+	gconf_client_commit_change_set (xkbConfig->confClient, cs, TRUE,
+					&gerror);
+	if (gerror != NULL) {
+		g_warning ("Error saving backup configuration: %s\n",
 			   gerror->message);
 		g_error_free (gerror);
 		gerror = NULL;
@@ -683,15 +714,16 @@ GSwitchItXkbConfigOptionsIsSet (GSwitchItXkbConfig * xkbConfig,
 gboolean
 GSwitchItXkbConfigActivate (GSwitchItXkbConfig * xkbConfig)
 {
-	return _GSwitchItXkbConfigDoWithSettings (xkbConfig, TRUE, NULL);
-}
+	gboolean rv = FALSE;
 
-gboolean
-GSwitchItXkbConfigDumpSettings (GSwitchItXkbConfig * xkbConfig,
-				const char *fileName)
-{
-	return _GSwitchItXkbConfigDoWithSettings (xkbConfig, FALSE,
-						  fileName);
+	XklConfigRec data;
+	XklConfigRecInit (&data);
+
+	_GSwitchItXkbConfigCopyToXklConfig (xkbConfig, &data);
+
+	rv = XklConfigActivate (&data);
+	XklConfigRecDestroy (&data);
+	return rv;
 }
 
 void
@@ -1071,10 +1103,6 @@ GSwitchItAppletConfigStopListen (GSwitchItAppletConfig * appletConfig)
 {
 	_GSwitchItConfigRemoveListener (appletConfig->confClient,
 					&gconfAppletListenerId);
-	_GSwitchItConfigRemoveListener (appletConfig->confClient,
-					&gconfImagesListenerId);
-	_GSwitchItConfigRemoveListener (appletConfig->confClient,
-					&gconfCommandsListenerId);
 }
 
 Bool
@@ -1124,8 +1152,8 @@ GSwitchItAppletConfigLoadGroupDescriptionsUtf8 (GSwitchItAppletConfig *
 			    *pNativeNames++);
 
 	pDest = (char *) namesToFill;
-	if (XklMultipleLayoutsSupported ()
-	    && appletConfig->layoutNamesAsGroupNames) {
+	if ((XklGetBackendFeatures() & XKLF_MULTIPLE_LAYOUTS_SUPPORTED) && 
+            appletConfig->layoutNamesAsGroupNames) {
 		XklConfigRec xklConfig;
 		if (XklConfigGetFromServer (&xklConfig)) {
 			char **pl = xklConfig.layouts;
