@@ -29,8 +29,6 @@
 #include <libgnomeui/gnome-window-icon.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <libart_lgpl/libart.h>
-#include <egg-screen-exec.h>
-#include <egg-screen-help.h>
 
 #include "global.h"
 
@@ -40,8 +38,6 @@ about_cb (BonoboUIComponent *uic,
 	  const char        *name)
 {
     GdkPixbuf        *pixbuf;
-    GError           *error = NULL;
-    gchar            *file;
    
     static const gchar *authors[] =
     {
@@ -67,15 +63,8 @@ about_cb (BonoboUIComponent *uic,
 	return;
     }
 	
-    file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-monitor.png", FALSE, NULL);
-    pixbuf = gdk_pixbuf_new_from_file (file, &error);
-    g_free (file);
-   
-    if (error) {
-	g_warning (G_STRLOC ": cannot open %s: %s", file, error->message);
-	g_error_free (error);
-    }
-
+    pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
+		    "gnome-monitor", 48, 0, NULL);
 	
     ma->about_dialog = gnome_about_new (_("System Monitor"), VERSION,
 					"(C) 1999 - 2002 The Free Software Foundation",
@@ -107,7 +96,7 @@ help_cb (BonoboUIComponent *uic,
 
  	GError *error = NULL;
                                                                                 
-    	egg_help_display_on_screen (
+    	gnome_help_display_on_screen (
                 "multiload", NULL,
                 gtk_widget_get_screen (GTK_WIDGET (ma->applet)),
                 &error);
@@ -187,32 +176,44 @@ multiload_change_orient_cb(PanelApplet *applet, gint arg1, gpointer data)
 }
 
 void
-multiload_change_background_cb(PanelApplet *a, PanelAppletBackgroundType type,
-				GdkColor *color, GdkPixmap *pixmap,
+multiload_change_background_cb (PanelApplet *a,
+				PanelAppletBackgroundType type,
+				GdkColor *color,
+				GdkPixmap *pixmap,
 				gpointer *data)
 {
-	MultiloadApplet *ma = data;
-	GtkRcStyle *rc_style = gtk_rc_style_new ();
+	/* Taken from Trash Applet */
+	MultiloadApplet *ma = (MultiloadApplet *) data;
+	GtkRcStyle *rc_style;
+	GtkStyle *style;
+	
+	/* reset style */
+	gtk_widget_set_style (GTK_WIDGET (ma->applet), NULL);
+	rc_style = gtk_rc_style_new ();
+	gtk_widget_modify_style (GTK_WIDGET (ma->applet), rc_style);
+	g_object_unref (rc_style);
 
 	switch (type) {
-		case PANEL_PIXMAP_BACKGROUND:
-			gtk_widget_modify_style (GTK_WIDGET (ma->applet), rc_style);
+		case PANEL_COLOR_BACKGROUND:
+			gtk_widget_modify_bg (GTK_WIDGET (ma->applet),
+					GTK_STATE_NORMAL, color);
 			break;
 
-		case PANEL_COLOR_BACKGROUND:
-			gtk_widget_modify_bg (GTK_WIDGET (ma->applet), GTK_STATE_NORMAL, color);
+		case PANEL_PIXMAP_BACKGROUND:
+			style = gtk_style_copy (GTK_WIDGET (ma->applet)->style);
+			if (style->bg_pixmap[GTK_STATE_NORMAL])
+				g_object_unref
+					(style->bg_pixmap[GTK_STATE_NORMAL]);
+			style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref
+				(pixmap);
+			gtk_widget_set_style (GTK_WIDGET (ma->applet), style);
 			break;
 
 		case PANEL_NO_BACKGROUND:
-			gtk_widget_modify_style (GTK_WIDGET (ma->applet), rc_style);
-			break;
-
 		default:
 			gtk_widget_modify_style (GTK_WIDGET (ma->applet), rc_style);
 			break;
 	}
-
-	gtk_rc_style_unref (rc_style);
 }
 
 void
@@ -458,7 +459,7 @@ multiload_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 	ma->about_dialog = NULL;
 	ma->prop_dialog = NULL;
 
-	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-monitor.png");
+	gtk_window_set_default_icon_name ("gnome-monitor");
 	
 	panel_applet_add_preferences (applet, "/schemas/apps/multiload/prefs", NULL);
 	panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
