@@ -35,8 +35,6 @@
 #include <panel-applet-gconf.h>
 #include <glade/glade.h>
 
-#include <egg-screen-help.h>
-
 #define CFG_DEVICE "eth0"
 #define CFG_UPDATE_INTERVAL 2
 
@@ -47,7 +45,7 @@ typedef enum {
 	PIX_SIGNAL_2,
 	PIX_SIGNAL_3,
 	PIX_SIGNAL_4,
-	PIX_NUMBER,
+	PIX_NUMBER
 } PixmapState;
 
 static char * pixmap_names[] = {
@@ -85,7 +83,7 @@ typedef struct {
 static GladeXML *xml = NULL;
 static gchar* glade_file=NULL;
 
-static void show_error_dialog (gchar*,...);
+static void show_error_dialog (WirelessApplet *applet, gchar*,...);
 static void show_warning_dialog (gchar*,...);
 static int wireless_applet_timeout_handler (WirelessApplet *applet);
 static void wireless_applet_properties_dialog (BonoboUIComponent *uic,
@@ -136,25 +134,29 @@ static void
 wireless_applet_draw (WirelessApplet *applet, int percent)
 {
 	const char *label_text;
-	char *tmp;
+	char *lbl;
+	char *tltp;
 	PixmapState state;
 
-	/* Update the percentage */
+	/* Update the label and the tooltip if necessary */
 	if (percent > 0) {
-		tmp = g_strdup_printf ("%2.0d%%", percent);
+		lbl = g_strdup_printf ("%2.0d%%", percent);
+		tltp = g_strdup_printf (_("Link Strength: %2.0d%%"), percent);
 	} else {
-		tmp = g_strdup_printf (_("N/A"));
+		lbl = g_strdup_printf (_("N/A"));
+		tltp = g_strdup_printf (_("N/A"));
 	}
 
 	label_text = gtk_label_get_text (GTK_LABEL (applet->pct_label));
-	if (g_strcasecmp (tmp, label_text) != 0)
+	if (g_strcasecmp (lbl, label_text) != 0)
 	{
+		gtk_label_set_text (GTK_LABEL (applet->pct_label), lbl);
 		gtk_tooltips_set_tip (applet->tips,
 				GTK_WIDGET (applet),
-				tmp, NULL);
-		gtk_label_set_text (GTK_LABEL (applet->pct_label), tmp);
+				tltp, NULL);
 	}
-	g_free (tmp);
+	g_free (lbl);
+	g_free (tltp);
 
 	/* Update the image */
 	percent = CLAMP (percent, -1, 100);
@@ -322,7 +324,7 @@ wireless_applet_timeout_handler (WirelessApplet *applet)
 
 
 static void 
-show_error_dialog (gchar *mesg,...) 
+show_error_dialog (WirelessApplet *applet, gchar *mesg,...) 
 {
 	GtkWidget *dialog;
 	char *tmp;
@@ -333,6 +335,8 @@ show_error_dialog (gchar *mesg,...)
 	dialog = gtk_message_dialog_new (NULL,
 			0, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
 			mesg, NULL);
+	gtk_window_set_screen (GTK_WINDOW (dialog),
+			       gtk_widget_get_screen (GTK_WIDGET (applet)));
 	gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 	g_free (tmp);
@@ -362,11 +366,7 @@ start_file_read (WirelessApplet *applet)
 {
 	applet->file = fopen ("/proc/net/wireless", "rt");
 	if (applet->file == NULL) {
-		gtk_tooltips_set_tip (applet->tips,
-				GTK_WIDGET (applet),
-				_("No Wireless Devices"),
-				NULL);
-		show_error_dialog (_("There doesn't seem to be any wireless devices configured on your system.\nPlease verify your configuration if you think this is incorrect."));
+		show_error_dialog (applet, _("There doesn't seem to be any wireless devices configured on your system.\nPlease verify your configuration if you think this is incorrect."));
 	}
 }
 
@@ -534,7 +534,7 @@ static void
 wireless_applet_help_cb (BonoboUIComponent *uic, WirelessApplet *applet)
 {
 	GError *error = NULL;
-	egg_help_display_on_screen ("wireless", NULL,
+	gnome_help_display_on_screen ("wireless", NULL,
 				   gtk_widget_get_screen (GTK_WIDGET (
 						applet)), &error);
 	if (error) {
@@ -615,7 +615,7 @@ prefs_response_cb (GtkDialog *dialog, gint response, gpointer data)
 {
 	GError *error = NULL;
 	if (response == GTK_RESPONSE_HELP) {
-		egg_help_display_on_screen ("wireless", "wireless-prefs",
+		gnome_help_display_on_screen ("wireless", "wireless-prefs",
 					    gtk_widget_get_screen (GTK_WIDGET (
 					    dialog)), &error);
 		if (error) {
@@ -826,6 +826,11 @@ wireless_applet_new (WirelessApplet *applet)
 	start_file_read (applet);
 	wireless_applet_timeout_handler (applet);
 
+	gtk_tooltips_set_tip (applet->tips,
+			      GTK_WIDGET (applet),
+			      _("No Wireless Devices"),
+			      NULL);
+
 	applet->timeout_handler_id = gtk_timeout_add
 		(CFG_UPDATE_INTERVAL * 1000,
 		 (GtkFunction)wireless_applet_timeout_handler,
@@ -851,8 +856,7 @@ wireless_applet_new (WirelessApplet *applet)
 static gboolean
 wireless_applet_fill (WirelessApplet *applet)
 {
-	gnome_window_icon_set_default_from_file
-		(ICONDIR"/wireless-applet/wireless-applet.png");
+	gtk_window_set_default_icon_name ("wireless-applet");
 
 	glade_gnome_init ();
 	glade_file = gnome_program_locate_file
